@@ -26,9 +26,11 @@ ztpoisson <- function(lambdaLink = c("log", "neglog"),
       )
     } else {
       switch (type,
-        "nontrunc" = lambdaLink(eta, inverse = TRUE, deriv = 1),
-        "trunc" = lambdaLink(eta, inverse = TRUE, deriv = 1) *
-          (exp(lambda) * (exp(lambda) - lambda - 1)) / (exp(lambda) - 1) ^ 2
+        "nontrunc" = cbind(lambdaLink(eta, inverse = TRUE, deriv = 1)),
+        "trunc" = cbind(
+          lambdaLink(eta, inverse = TRUE, deriv = 1) *
+            (exp(lambda) * (exp(lambda) - lambda - 1)) / (exp(lambda) - 1) ^ 2
+        )
       )
     }
   }
